==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/AutoscaleProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.AutoscaleProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Autoscale profile.
 * @property capacity the number of instances that can be used during this profile.
 * @property fixedDate the specific date-time for the profile. This element is not used if the Recurrence element is used.
 * @property name the name of the profile.
 * @property recurrence the repeating times at which this profile begins. This element is not used if the FixedDate element is used.
 * @property rules the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
 */
public data class AutoscaleProfileArgs(
    public val capacity: Output<ScaleCapacityArgs>,
    public val fixedDate: Output<TimeWindowArgs>? = null,
    public val name: Output<String>,
    public val recurrence: Output<RecurrenceArgs>? = null,
    public val rules: Output<List<ScaleRuleArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.AutoscaleProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.AutoscaleProfileArgs =
        com.pulumi.azurenative.insights.inputs.AutoscaleProfileArgs.builder()
            .capacity(capacity.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .fixedDate(fixedDate?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name.applyValue({ args0 -> args0 }))
            .recurrence(recurrence?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .rules(
                rules.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AutoscaleProfileArgs].
 */
@PulumiTagMarker
public class AutoscaleProfileArgsBuilder internal constructor() {
    private var capacity: Output<ScaleCapacityArgs>? = null

    private var fixedDate: Output<TimeWindowArgs>? = null

    private var name: Output<String>? = null

    private var recurrence: Output<RecurrenceArgs>? = null

    private var rules: Output<List<ScaleRuleArgs>>? = null

    /**
     * @param value the number of instances that can be used during this profile.
     */
    @JvmName("pigakrhgrmwcysau")
    public suspend fun capacity(`value`: Output<ScaleCapacityArgs>) {
        this.capacity = value
    }

    /**
     * @param value the specific date-time for the profile. This element is not used if the Recurrence element is used.
     */
    @JvmName("wvbhdxgjwyrhcort")
    public suspend fun fixedDate(`value`: Output<TimeWindowArgs>) {
        this.fixedDate = value
    }

    /**
     * @param value the name of the profile.
     */
    @JvmName("lxvvswqsiumadlfm")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value the repeating times at which this profile begins. This element is not used if the FixedDate element is used.
     */
    @JvmName("phwgamayeahitybm")
    public suspend fun recurrence(`value`: Output<RecurrenceArgs>) {
        this.recurrence = value
    }

    /**
     * @param value the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("anlcpmkckvqffaag")
    public suspend fun rules(`value`: Output<List<ScaleRuleArgs>>) {
        this.rules = value
    }

    @JvmName("dwstffedvlgplxcb")
    public suspend fun rules(vararg values: Output<ScaleRuleArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("mfkgkyhwambmblaf")
    public suspend fun rules(values: List<Output<ScaleRuleArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value the number of instances that can be used during this profile.
     */
    @JvmName("iikjvetqknwlwnxu")
    public suspend fun capacity(`value`: ScaleCapacityArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.capacity = mapped
    }

    /**
     * @param argument the number of instances that can be used during this profile.
     */
    @JvmName("elctsmecbinwjqul")
    public suspend fun capacity(argument: suspend ScaleCapacityArgsBuilder.() -> Unit) {
        val toBeMapped = ScaleCapacityArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.capacity = mapped
    }

    /**
     * @param value the specific date-time for the profile. This element is not used if the Recurrence element is used.
     */
    @JvmName("rgcwbmfjedlqnoeo")
    public suspend fun fixedDate(`value`: TimeWindowArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fixedDate = mapped
    }

    /**
     * @param argument the specific date-time for the profile. This element is not used if the Recurrence element is used.
     */
    @JvmName("erdwxwrhtsyrpqxc")
    public suspend fun fixedDate(argument: suspend TimeWindowArgsBuilder.() -> Unit) {
        val toBeMapped = TimeWindowArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.fixedDate = mapped
    }

    /**
     * @param value the name of the profile.
     */
    @JvmName("garnfrpgrpxgmwuf")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value the repeating times at which this profile begins. This element is not used if the FixedDate element is used.
     */
    @JvmName("ifwislvapyjecnqu")
    public suspend fun recurrence(`value`: RecurrenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recurrence = mapped
    }

    /**
     * @param argument the repeating times at which this profile begins. This element is not used if the FixedDate element is used.
     */
    @JvmName("mopdmltwifjjlybo")
    public suspend fun recurrence(argument: suspend RecurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = RecurrenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.recurrence = mapped
    }

    /**
     * @param value the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("wmrpkubyctvsuffs")
    public suspend fun rules(`value`: List<ScaleRuleArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("laofosheffadpasx")
    public suspend fun rules(argument: List<suspend ScaleRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ScaleRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("cigkdvepjfivikrq")
    public suspend fun rules(vararg argument: suspend ScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ScaleRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("uvdvjatljiqdsomg")
    public suspend fun rules(argument: suspend ScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("ujyoikcudbslspup")
    public suspend fun rules(vararg values: ScaleRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): AutoscaleProfileArgs = AutoscaleProfileArgs(
        capacity = capacity ?: throw PulumiNullFieldException("capacity"),
        fixedDate = fixedDate,
        name = name ?: throw PulumiNullFieldException("name"),
        recurrence = recurrence,
        rules = rules ?: throw PulumiNullFieldException("rules"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/AutoscaleProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.AutoscaleProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Autoscale profile.
 * @property capacity the number of instances that can be used during this profile.
 * @property fixedDate the specific date-time for the profile. This element is not used if the Recurrence element is used.
 * @property name the name of the profile.
 * @property recurrence the repeating times at which this profile begins. This element is not used if the FixedDate element is used.
 * @property rules the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
 */
public data class AutoscaleProfileArgs(
    public val capacity: Output<ScaleCapacityArgs>,
    public val fixedDate: Output<TimeWindowArgs>? = null,
    public val name: Output<String>,
    public val recurrence: Output<RecurrenceArgs>? = null,
    public val rules: Output<List<ScaleRuleArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.AutoscaleProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.AutoscaleProfileArgs =
        com.pulumi.azurenative.insights.inputs.AutoscaleProfileArgs.builder()
            .capacity(capacity.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .fixedDate(fixedDate?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .name(name.applyValue({ args0 -> args0 }))
            .recurrence(recurrence?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .rules(
                rules.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AutoscaleProfileArgs].
 */
@PulumiTagMarker
public class AutoscaleProfileArgsBuilder internal constructor() {
    private var capacity: Output<ScaleCapacityArgs>? = null

    private var fixedDate: Output<TimeWindowArgs>? = null

    private var name: Output<String>? = null

    private var recurrence: Output<RecurrenceArgs>? = null

    private var rules: Output<List<ScaleRuleArgs>>? = null

    /**
     * @param value the number of instances that can be used during this profile.
     */
    @JvmName("oreowpuxgqrafuwx")
    public suspend fun capacity(`value`: Output<ScaleCapacityArgs>) {
        this.capacity = value
    }

    /**
     * @param value the specific date-time for the profile. This element is not used if the Recurrence element is used.
     */
    @JvmName("lppbotbtapylpjmt")
    public suspend fun fixedDate(`value`: Output<TimeWindowArgs>) {
        this.fixedDate = value
    }

    /**
     * @param value the name of the profile.
     */
    @JvmName("ggolnrvrrsmchgex")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value the repeating times at which this profile begins. This element is not used if the FixedDate element is used.
     */
    @JvmName("eksspfpraefiibea")
    public suspend fun recurrence(`value`: Output<RecurrenceArgs>) {
        this.recurrence = value
    }

    /**
     * @param value the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("dixkglsvetvlihsw")
    public suspend fun rules(`value`: Output<List<ScaleRuleArgs>>) {
        this.rules = value
    }

    @JvmName("esiejfgnfmaemlut")
    public suspend fun rules(vararg values: Output<ScaleRuleArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("pfrelldyjlnodvug")
    public suspend fun rules(values: List<Output<ScaleRuleArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value the number of instances that can be used during this profile.
     */
    @JvmName("xfkmfovyycjuhhqu")
    public suspend fun capacity(`value`: ScaleCapacityArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.capacity = mapped
    }

    /**
     * @param argument the number of instances that can be used during this profile.
     */
    @JvmName("latcedikumoytnja")
    public suspend fun capacity(argument: suspend ScaleCapacityArgsBuilder.() -> Unit) {
        val toBeMapped = ScaleCapacityArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.capacity = mapped
    }

    /**
     * @param value the specific date-time for the profile. This element is not used if the Recurrence element is used.
     */
    @JvmName("psswfffnruolqsuy")
    public suspend fun fixedDate(`value`: TimeWindowArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fixedDate = mapped
    }

    /**
     * @param argument the specific date-time for the profile. This element is not used if the Recurrence element is used.
     */
    @JvmName("gqxkculswngtfoav")
    public suspend fun fixedDate(argument: suspend TimeWindowArgsBuilder.() -> Unit) {
        val toBeMapped = TimeWindowArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.fixedDate = mapped
    }

    /**
     * @param value the name of the profile.
     */
    @JvmName("jkwtlcbnkdnfyrvl")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value the repeating times at which this profile begins. This element is not used if the FixedDate element is used.
     */
    @JvmName("oekhaplfviqwwpyf")
    public suspend fun recurrence(`value`: RecurrenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recurrence = mapped
    }

    /**
     * @param argument the repeating times at which this profile begins. This element is not used if the FixedDate element is used.
     */
    @JvmName("cyorokldebfjjejw")
    public suspend fun recurrence(argument: suspend RecurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = RecurrenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.recurrence = mapped
    }

    /**
     * @param value the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("dhqpsnwdfijtdtbh")
    public suspend fun rules(`value`: List<ScaleRuleArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("hlsdixcqfnteerhw")
    public suspend fun rules(argument: List<suspend ScaleRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ScaleRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("agcjxpemuwyhlpir")
    public suspend fun rules(vararg argument: suspend ScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ScaleRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("ugktmqbpmbjsqcgn")
    public suspend fun rules(argument: suspend ScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values the collection of rules that provide the triggers and parameters for the scaling action. A maximum of 10 rules can be specified.
     */
    @JvmName("cehblagiudmowcel")
    public suspend fun rules(vararg values: ScaleRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): AutoscaleProfileArgs = AutoscaleProfileArgs(
        capacity = capacity ?: throw PulumiNullFieldException("capacity"),
        fixedDate = fixedDate,
        name = name ?: throw PulumiNullFieldException("name"),
        recurrence = recurrence,
        rules = rules ?: throw PulumiNullFieldException("rules"),
    )
}
